@@ -11,22 +11,22 @@ import (
 func TestIacChainSupplier_Resources(t *testing.T) {
 	tests := []struct {
 		name          string
-		initSuppliers func(suppliers *[]resource.Supplier)
+		initSuppliers func(suppliers *[]resource.IaCSupplier)
 		want          []*resource.Resource
 		wantErr       bool
 	}{
 		{
 			name: "All failed",
-			initSuppliers: func(suppliers *[]resource.Supplier) {
-				sup := &resource.MockSupplier{}
+			initSuppliers: func(suppliers *[]resource.IaCSupplier) {
+				sup := &resource.MockIaCSupplier{}
 				sup.On("Resources").Return(nil, errors.New("1"))
 				*suppliers = append(*suppliers, sup)
 
-				sup = &resource.MockSupplier{}
+				sup = &resource.MockIaCSupplier{}
 				sup.On("Resources").Return(nil, errors.New("2"))
 				*suppliers = append(*suppliers, sup)
 
-				sup = &resource.MockSupplier{}
+				sup = &resource.MockIaCSupplier{}
 				sup.On("Resources").Return(nil, errors.New("3"))
 				*suppliers = append(*suppliers, sup)
 			},
@@ -35,16 +35,16 @@ func TestIacChainSupplier_Resources(t *testing.T) {
 		},
 		{
 			name: "Partial failed",
-			initSuppliers: func(suppliers *[]resource.Supplier) {
-				sup := &resource.MockSupplier{}
+			initSuppliers: func(suppliers *[]resource.IaCSupplier) {
+				sup := &resource.MockIaCSupplier{}
 				sup.On("Resources").Return(nil, errors.New("1"))
 				*suppliers = append(*suppliers, sup)
 
-				sup = &resource.MockSupplier{}
+				sup = &resource.MockIaCSupplier{}
 				sup.On("Resources").Return(nil, errors.New("2"))
 				*suppliers = append(*suppliers, sup)
 
-				sup = &resource.MockSupplier{}
+				sup = &resource.MockIaCSupplier{}
 				sup.On("Resources").Return([]*resource.Resource{
 					&resource.Resource{
 						Id:    "ID",
@@ -67,7 +67,7 @@ func TestIacChainSupplier_Resources(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			r := NewIacChainSupplier()
-			suppliers := make([]resource.Supplier, 0)
+			suppliers := make([]resource.IaCSupplier, 0)
 			tt.initSuppliers(&suppliers)
 
 			for _, supplier := range suppliers {
