@@ -11,18 +11,20 @@ type StateEnumerator interface {
 	Enumerate() ([]string, error)
 }
 
-func GetEnumerator(config config.SupplierConfig) StateEnumerator {
+func GetEnumerator(config config.SupplierConfig, opts *backend.Options) (StateEnumerator, error) {
 
 	switch config.Backend {
 	case backend.BackendKeyFile:
-		return NewFileEnumerator(config)
+		return NewFileEnumerator(config), nil
 	case backend.BackendKeyS3:
-		return NewS3Enumerator(config)
+		return NewS3Enumerator(config), nil
+	case backend.BackendKeyAzureRM:
+		return NewAzureRMEnumerator(config, opts.AzureRMBackendOptions)
 	}
 
 	logrus.WithFields(logrus.Fields{
 		"backend": config.Backend,
 	}).Debug("No enumerator for backend")
 
-	return nil
+	return nil, nil
 }
