@@ -129,6 +129,7 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "IAM role policy", dirName: "aws_iam_role_policy_multiple", wantErr: false},
 		{name: "IAM role policy attachment", dirName: "aws_iam_role_policy_attachment", wantErr: false},
 		{name: "IAM user policy attachment", dirName: "aws_iam_user_policy_attachment", wantErr: false},
+		{name: "IAM group policy", dirName: "aws_iam_group_policy", wantErr: false},
 		{name: "VPC security group rule", dirName: "aws_vpc_security_group_rule", wantErr: false},
 		{name: "route table", dirName: "aws_route_table", wantErr: false},
 		{name: "route table associations", dirName: "aws_route_assoc", wantErr: false},
@@ -192,6 +193,8 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "App autoscaling scheduled action", dirName: "aws_appautoscaling_scheduled_action", wantErr: false},
 		{name: "Launch template", dirName: "aws_launch_template", wantErr: false},
 		{name: "Launch configuration", dirName: "aws_launch_configuration", wantErr: false},
+		{name: "EBS encryption by default", dirName: "aws_ebs_encryption_by_default", wantErr: false},
+		{name: "LoadBalancer", dirName: "aws_lb", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -378,6 +381,8 @@ func TestTerraformStateReader_Google_Resources(t *testing.T) {
 		{name: "cloudrun service", dirName: "google_cloudrun_service", wantErr: false},
 		{name: "compute node group", dirName: "google_compute_node_group", wantErr: false},
 		{name: "compute forwarding rule", dirName: "google_compute_forwarding_rule", wantErr: false},
+		{name: "compute instance group manager", dirName: "google_compute_instance_group_manager", wantErr: false},
+		{name: "compute global forwarding rule", dirName: "google_compute_global_forwarding_rule", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
