@@ -56,6 +56,7 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsDefaultSubnetResourceType:                   {resource.FlagDeepMode},
 		AwsDefaultVpcResourceType:                      {resource.FlagDeepMode},
 		AwsDynamodbTableResourceType:                   {resource.FlagDeepMode},
+		AwsEbsEncryptionByDefaultResourceType:          {resource.FlagDeepMode},
 		AwsEbsSnapshotResourceType:                     {resource.FlagDeepMode},
 		AwsEbsVolumeResourceType:                       {resource.FlagDeepMode},
 		AwsEcrRepositoryResourceType:                   {resource.FlagDeepMode},
@@ -70,6 +71,7 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsIamUserResourceType:                         {resource.FlagDeepMode},
 		AwsIamUserPolicyResourceType:                   {resource.FlagDeepMode},
 		AwsIamUserPolicyAttachmentResourceType:         {resource.FlagDeepMode},
+		AwsIamGroupPolicyResourceType:                  {},
 		AwsInstanceResourceType:                        {resource.FlagDeepMode},
 		AwsInternetGatewayResourceType:                 {resource.FlagDeepMode},
 		AwsKeyPairResourceType:                         {resource.FlagDeepMode},
@@ -105,6 +107,8 @@ func TestAWS_Metadata_Flags(t *testing.T) {
 		AwsNetworkACLRuleResourceType:                  {resource.FlagDeepMode},
 		AwsLaunchTemplateResourceType:                  {resource.FlagDeepMode},
 		AwsLaunchConfigurationResourceType:             {},
+		AwsLoadBalancerResourceType:                    {},
+		AwsApplicationLoadBalancerResourceType:         {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository(tf.AWS, "3.19.0")
