@@ -24,7 +24,12 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_dynamodb_table": {},
 	"aws_ebs_snapshot":   {},
 	"aws_ebs_volume":     {},
-	"aws_ecr_repository": {},
+	"aws_alb": {children: []ResourceType{
+		"aws_lb",
+	}},
+	"aws_lb":                        {},
+	"aws_ebs_encryption_by_default": {},
+	"aws_ecr_repository":            {},
 	"aws_eip": {children: []ResourceType{
 		"aws_eip_association",
 	}},
@@ -51,6 +56,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_iam_user_policy_attachment": {children: []ResourceType{
 		"aws_iam_policy_attachment",
 	}},
+	"aws_iam_group_policy": {},
 	"aws_instance": {children: []ResourceType{
 		"aws_ebs_volume",
 	}},
@@ -186,19 +192,21 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"google_project_iam_policy": {children: []ResourceType{
 		"google_project_iam_member",
 	}},
-	"google_compute_address":         {},
-	"google_compute_subnetwork":      {},
-	"google_cloudfunctions_function": {},
-	"google_compute_disk":            {},
-	"google_bigtable_instance":       {},
-	"google_bigtable_table":          {},
-	"google_sql_database_instance":   {},
-	"google_compute_image":           {},
-	"google_compute_health_check":    {},
-	"google_compute_global_address":  {},
-	"google_compute_node_group":      {},
-	"google_cloud_run_service":       {},
-	"google_compute_forwarding_rule": {},
+	"google_compute_address":                {},
+	"google_compute_subnetwork":             {},
+	"google_cloudfunctions_function":        {},
+	"google_compute_disk":                   {},
+	"google_bigtable_instance":              {},
+	"google_bigtable_table":                 {},
+	"google_sql_database_instance":          {},
+	"google_compute_image":                  {},
+	"google_compute_health_check":           {},
+	"google_compute_global_address":         {},
+	"google_compute_node_group":             {},
+	"google_cloud_run_service":              {},
+	"google_compute_forwarding_rule":        {},
+	"google_compute_instance_group_manager": {},
+	"google_compute_global_forwarding_rule": {},
 
 	"azurerm_storage_account":   {},
 	"azurerm_storage_container": {},
