@@ -28,20 +28,32 @@ if ! $GHCLI_BIN auth status &> /dev/null; then
     exit 1
 fi
 
+echo "Finding merged pull requests between $BASE_TAG and $LATEST_TAG..."
+
 # Compare $BASE_TAG branch with the latest tag
 # Keep IDs of merged pull requests
 PRs=$(git log --pretty=oneline "$BASE_TAG"..."$LATEST_TAG" | grep 'Merge pull request #' | grep -oE '#[0-9]+' | sed 's/#//')
 
 # Find fixed issues from $BASE_TAG to $LATEST_TAG
+EXIT_CODE=0
 ISSUES=()
 for pr in $PRs; do
-    id=$($GHCLI_BIN pr view "$pr" --json body | grep -oE 'Related issues | (.*)?[0-9]+(.*)?\|' | sed 's/[^[:digit:]]//g' | sed -z 's/\n//g' || true)
+    id=$($GHCLI_BIN pr view "$pr" --json body | grep -oE '(Related issues \| )(.*)?[0-9]+(.*|\r|\n)?(\|)' | sed 's/[^[:digit:]]//g' | sed -z 's/\n//g' || true)
     if [ -z "$id" ]; then
         continue
     fi
+    if ! $GHCLI_BIN issue view "$id" --json title &> /dev/null; then
+        echo "Invalid issue $id for pull request $pr. Skipping."
+        EXIT_CODE=1
+        continue
+    fi
     ISSUES+=("$id")
 done
 
+# Remove duplicate IDs
+# This can happen when we release using a separate branch (e.g. patch releases)
+mapfile -t ISSUES < <(printf "%s\n" "${ISSUES[@]}" | sort -u)
+
 echo "Creating milestone $LATEST_TAG in github.com/$REPO"
 curl -X POST \
     -H "Accept: application/vnd.github.v3+json" \
@@ -56,8 +68,9 @@ for issue in "${ISSUES[@]}"; do
     curl -X POST \
         -H "Accept: application/vnd.github.v3+json" \
         -H "Authorization: token $GITHUB_TOKEN" \
-        --data "{\"body\":\"This issue has been referenced in the latest release $LATEST_TAG.\"}" \
+        --data "{\"body\":\"This issue has been referenced in the [$LATEST_TAG release](https://github.com/$REPO/releases/tag/$LATEST_TAG).\"}" \
         "https://api.github.com/repos/$REPO/issues/$issue/comments"
 done
 
 echo "Done."
+exit $EXIT_CODE
